Discussion:
Bug#994121: debian-cd: Default CODENAME should be changed to bookworm (testing)
(too old to reply)
Daniel Lewart
2021-09-12 09:50:01 UTC
Permalink
Source: debian-cd
Version: 3.1.35
Severity: normal
Tags: patch
X-Debbugs-Cc: ***@gmail.com

Debian CD Group,

The default CODENAME should be changed to bookworm (testing).

Below is a patch, which I successfully tested with:
$ ./easy-build.sh NETINST

Thank you!
Daniel Lewart
Urbana, Illinois
---
diff -ru a/easy-build.sh b/easy-build.sh
--- a/easy-build.sh 2021-09-06 05:22:44.000000000 -0500
+++ b/easy-build.sh 2021-09-12 00:00:00.000000000 -0500
@@ -72,10 +72,10 @@
## For what release to build images

# The suite the installed system will be based on
-export CODENAME=buster
+export CODENAME=bookworm
# The suite from which the udebs for the installer will be taken (normally
# the same as CODENAME)
-export DI_CODENAME=buster
+export DI_CODENAME=bookworm


## The debian-installer images to use. This must match the suite (DI_CODENAME)
###
Daniel Lewart
2021-09-12 10:00:02 UTC
Permalink
Makefile patch is attached. Dan
Steve McIntyre
2021-09-22 20:50:01 UTC
Permalink
Hi Daniel!
Post by Daniel Lewart
Source: debian-cd
Version: 3.1.35
Severity: normal
Tags: patch
Debian CD Group,
The default CODENAME should be changed to bookworm (testing).
$ ./easy-build.sh NETINST
Thank you!
Daniel Lewart
Urbana, Illinois
Thanks for the patches. (Mostly) applied, but please don't make
unrelated changes when you send patches. In this case, I've *not*
changed the CONTRIB setting.
Post by Daniel Lewart
---
diff -ru a/easy-build.sh b/easy-build.sh
--- a/easy-build.sh 2021-09-06 05:22:44.000000000 -0500
+++ b/easy-build.sh 2021-09-12 00:00:00.000000000 -0500
@@ -72,10 +72,10 @@
## For what release to build images
# The suite the installed system will be based on
-export CODENAME=buster
+export CODENAME=bookworm
# The suite from which the udebs for the installer will be taken (normally
# the same as CODENAME)
-export DI_CODENAME=buster
+export DI_CODENAME=bookworm
## The debian-installer images to use. This must match the suite (DI_CODENAME)
###
Makefile patch is attached. Dan
--- a/Makefile 2021-09-06 05:22:44.000000000 -0500
+++ b/Makefile 2021-09-12 00:00:00.000000000 -0500
@@ -191,14 +191,14 @@
fi
endif
-# Make sure unstable/sid points to testing/buster, as there is no build
+# Make sure unstable/sid points to testing/bookworm, as there is no build
# rule for unstable/sid.
$(Q)if [ ! -d $(BASEDIR)/data/sid ] ; then \
- ln -s buster $(BASEDIR)/data/sid ; \
+ ln -s bookworm $(BASEDIR)/data/sid ; \
fi
$(Q)if [ ! -d $(BASEDIR)/tools/boot/sid ] ; then \
- ln -s buster $(BASEDIR)/tools/boot/sid ; \
+ ln -s bookworm $(BASEDIR)/tools/boot/sid ; \
fi
#################
diff -ru a/CONF.sh b/CONF.sh
--- a/CONF.sh 2021-09-06 05:22:44.000000000 -0500
+++ b/CONF.sh 2021-09-12 00:00:00.000000000 -0500
@@ -70,7 +70,7 @@
export DI_CODENAME=$CODENAME
fi
# If you want backported d-i (e.g. by setting
-# DI_CODENAME=jessie-backports, then you'll almost definitely also
+# DI_CODENAME=bookworm-backports, then you'll almost definitely also
# want to enable BACKPORTS below as well

# Should we include some packages from backports? If so, point at a
@@ -86,8 +86,8 @@
# the Debian mirror.
#export DI_WWW_HOME=default

-# Version number, "2.2 r0", "2.2 r1" etc.
-export DEBVERSION="11.0.0"
+# Version number, "10.11.0", "11.1.0", "testing", etc
+export DEBVERSION="testing"

# Official or non-official set.
# NOTE: THE "OFFICIAL" DESIGNATION IS ONLY ALLOWED FOR IMAGES AVAILABLE
@@ -136,7 +136,7 @@
# export NONFREE=1

# Do I want to have CONTRIB merged in the CD set
-export CONTRIB=1
+# export CONTRIB=1

# Do I want to have NONFREE on a separate CD (the last CD of the CD set)
# WARNING: Don't use NONFREE and EXTRANONFREE at the same time !
@@ -208,8 +208,8 @@

# Extra keys that you might want apt to trust. List their fingerprints
# here and debian-cd will grab them from the user's keyring as needed
-# (The example here is the buster release key)
-#export ARCHIVE_EXTRA_KEYS="80D15823B7FD1561F9F7BCDDDC30D7C23CBBABEE"
+# (The example here is the bullseye release key)
+#export ARCHIVE_EXTRA_KEYS="1F89983E0081FDE018F3CC9673A4F27B8DD47936"

# By default we use debootstrap --no-check-gpg to find out the minimal set
# of packages because there's no reason to not trust the local mirror. But
diff -ru a/CONF.sh b/CONF.sh
--- a/CONF.sh 2021-09-06 05:22:44.000000000 -0500
+++ b/CONF.sh 2021-09-12 00:00:00.000000000 -0500
@@ -70,7 +70,7 @@
export DI_CODENAME=$CODENAME
fi
# If you want backported d-i (e.g. by setting
-# DI_CODENAME=jessie-backports, then you'll almost definitely also
+# DI_CODENAME=bookworm-backports, then you'll almost definitely also
# want to enable BACKPORTS below as well
# Should we include some packages from backports? If so, point at a
@@ -86,8 +86,8 @@
# the Debian mirror.
#export DI_WWW_HOME=default
-# Version number, "2.2 r0", "2.2 r1" etc.
-export DEBVERSION="11.0.0"
+# Version number, "10.11.0", "11.1.0", "testing", etc
+export DEBVERSION="testing"
# Official or non-official set.
# NOTE: THE "OFFICIAL" DESIGNATION IS ONLY ALLOWED FOR IMAGES AVAILABLE
@@ -136,7 +136,7 @@
# export NONFREE=1
# Do I want to have CONTRIB merged in the CD set
-export CONTRIB=1
+# export CONTRIB=1
# Do I want to have NONFREE on a separate CD (the last CD of the CD set)
# WARNING: Don't use NONFREE and EXTRANONFREE at the same time !
@@ -208,8 +208,8 @@
# Extra keys that you might want apt to trust. List their fingerprints
# here and debian-cd will grab them from the user's keyring as needed
-# (The example here is the buster release key)
-#export ARCHIVE_EXTRA_KEYS="80D15823B7FD1561F9F7BCDDDC30D7C23CBBABEE"
+# (The example here is the bullseye release key)
+#export ARCHIVE_EXTRA_KEYS="1F89983E0081FDE018F3CC9673A4F27B8DD47936"
# By default we use debootstrap --no-check-gpg to find out the minimal set
# of packages because there's no reason to not trust the local mirror. But
--
Steve McIntyre, Cambridge, UK. ***@einval.com
Can't keep my eyes from the circling sky,
Tongue-tied & twisted, Just an earth-bound misfit, I...
Debian Bug Tracking System
2023-01-15 12:50:01 UTC
Permalink
Your message dated Sun, 15 Jan 2023 12:35:05 +0000
with message-id <E1pH2E5-009iaN-***@fasolo.debian.org>
and subject line Bug#994121: fixed in debian-cd 3.1.36
has caused the Debian Bug report #994121,
regarding debian-cd: Default CODENAME should be changed to bookworm (testing)
to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact ***@bugs.debian.org
immediately.)
--
994121: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=994121
Debian Bug Tracking System
Contact ***@bugs.debian.org with problems
Loading...